summaryrefslogtreecommitdiffstats
path: root/kspread/dialogs/kspread_dlg_find.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/dialogs/kspread_dlg_find.cc')
-rw-r--r--kspread/dialogs/kspread_dlg_find.cc68
1 files changed, 34 insertions, 34 deletions
diff --git a/kspread/dialogs/kspread_dlg_find.cc b/kspread/dialogs/kspread_dlg_find.cc
index 397b31d8..954e0a5c 100644
--- a/kspread/dialogs/kspread_dlg_find.cc
+++ b/kspread/dialogs/kspread_dlg_find.cc
@@ -19,49 +19,49 @@
#include "kspread_dlg_find.h"
-#include <qcheckbox.h>
-#include <qlayout.h>
+#include <tqcheckbox.h>
+#include <tqlayout.h>
#include <klocale.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qcombobox.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqcombobox.h>
using namespace KSpread;
-FindOption::FindOption( QWidget *parent)
+FindOption::FindOption( TQWidget *tqparent)
{
- QVBoxLayout *layout = new QVBoxLayout(parent);
- m_moreOptions = new QPushButton( i18n( "More Options" ), parent );
- layout->addWidget( m_moreOptions );
+ TQVBoxLayout *tqlayout = new TQVBoxLayout(tqparent);
+ m_moreOptions = new TQPushButton( i18n( "More Options" ), tqparent );
+ tqlayout->addWidget( m_moreOptions );
- connect( m_moreOptions, SIGNAL( clicked () ), this, SLOT( slotMoreOptions() ) );
+ connect( m_moreOptions, TQT_SIGNAL( clicked () ), this, TQT_SLOT( slotMoreOptions() ) );
- m_findExtension = new QWidget( parent );
- layout->addWidget( m_findExtension );
- QVBoxLayout *layout1 = new QVBoxLayout( m_findExtension );
- m_searchInAllSheet = new QCheckBox( i18n( "Search entire sheet" ),m_findExtension );
- layout1->addWidget( m_searchInAllSheet );
+ m_findExtension = new TQWidget( tqparent );
+ tqlayout->addWidget( m_findExtension );
+ TQVBoxLayout *tqlayout1 = new TQVBoxLayout( m_findExtension );
+ m_searchInAllSheet = new TQCheckBox( i18n( "Search entire sheet" ),m_findExtension );
+ tqlayout1->addWidget( m_searchInAllSheet );
- QHBoxLayout *comboLayout = new QHBoxLayout( m_findExtension );
- QLabel *label = new QLabel( i18n( "Search in:" ), m_findExtension );
+ TQHBoxLayout *comboLayout = new TQHBoxLayout( m_findExtension );
+ TQLabel *label = new TQLabel( i18n( "Search in:" ), m_findExtension );
comboLayout->addWidget( label );
- m_searchIn = new QComboBox( m_findExtension );
+ m_searchIn = new TQComboBox( m_findExtension );
comboLayout->addWidget( m_searchIn );
- layout1->addLayout( comboLayout );
+ tqlayout1->addLayout( comboLayout );
- QStringList lst;
+ TQStringList lst;
lst << i18n( "Cell Values" );
lst << i18n( "Comments" );
m_searchIn->insertStringList( lst );
- comboLayout = new QHBoxLayout( m_findExtension );
- label = new QLabel( i18n( "Search direction:" ), m_findExtension );
+ comboLayout = new TQHBoxLayout( m_findExtension );
+ label = new TQLabel( i18n( "Search direction:" ), m_findExtension );
comboLayout->addWidget( label );
- m_searchDirection = new QComboBox( m_findExtension );
+ m_searchDirection = new TQComboBox( m_findExtension );
comboLayout->addWidget( m_searchDirection );
- layout1->addLayout( comboLayout );
+ tqlayout1->addLayout( comboLayout );
lst.clear();
lst << i18n( "Across then Down" );
@@ -115,17 +115,17 @@ bool FindOption::searchInAllSheet() const
return m_searchInAllSheet->isChecked();
}
-FindDlg::FindDlg(QWidget *parent, const char *name, long options, const QStringList &findStrings, bool hasSelection )
- : KFindDialog(parent,name,options,findStrings,hasSelection )
+FindDlg::FindDlg(TQWidget *tqparent, const char *name, long options, const TQStringList &findStrings, bool hasSelection )
+ : KFindDialog(tqparent,name,options,findStrings,hasSelection )
{
m_findOptions = new FindOption( findExtension() );
- connect( m_findOptions, SIGNAL( adjustSize() ), SLOT( slotAjustSize() ) );
- setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
+ connect( m_findOptions, TQT_SIGNAL( adjustSize() ), TQT_SLOT( slotAjustSize() ) );
+ tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum));
}
FindDlg::~FindDlg()
{
// no need to delete child widgets, Qt does it all for us
}
void FindDlg::slotAjustSize()
@@ -139,17 +139,17 @@ bool FindDlg::searchInAllSheet() const
}
-SearchDlg::SearchDlg(QWidget *parent, const char *name, long options, const QStringList &findStrings, const QStringList &replaceStrings, bool hasSelection )
- : KReplaceDialog(parent,name,options,findStrings,replaceStrings,hasSelection )
+SearchDlg::SearchDlg(TQWidget *tqparent, const char *name, long options, const TQStringList &findStrings, const TQStringList &replaceStrings, bool hasSelection )
+ : KReplaceDialog(tqparent,name,options,findStrings,replaceStrings,hasSelection )
{
m_findOptions = new FindOption( findExtension() );
- connect( m_findOptions, SIGNAL( adjustSize() ), SLOT( slotAjustSize() ) );
- setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
+ connect( m_findOptions, TQT_SIGNAL( adjustSize() ), TQT_SLOT( slotAjustSize() ) );
+ tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Minimum));
}
SearchDlg::~SearchDlg()
{
// no need to delete child widgets, Qt does it all for us
}
void SearchDlg::slotAjustSize()
@@ -115,17 +115,17 @@ bool FindOption::searchInAllSheet() const
FindDlg::~FindDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
void FindDlg::slotAjustSize()
@@ -139,17 +139,17 @@ bool FindDlg::searchInAllSheet() const
SearchDlg::~SearchDlg()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
void SearchDlg::slotAjustSize()